@@ -62,13 +62,13 @@ class Block(Calc):
         n, e = self.prog.author
         lines = self.ftitle("Credits")
         if n:
-            lines += "- Author: %s\n" % n
+            lines += "* Author: %s\n" % n
         if e:
-            lines += "- Email: %s\n" % e
+            lines += "* Email: `%s <mailto:%s>`_\n" % (e, e)
         while not lines.endswith("\n\n"):
             lines += "\n"
         pn = self.prog.project.name
-        lines += "Thank you for using %s!" % pn
+        lines += "Thank you for using ``%s``!" % pn
         return lines
 
     @staticmethod
