@@ -5,6 +5,10 @@ from petrus._core.calcs.Calc import Calc
 
 
 class File(Calc):
+    def _calc_core(self):
+        n = self.prog.project.name
+        return os.path.join("src", n, "core", "__init__.py")
+
     def _calc_gitignore(self):
         return ".gitignore"
 
@@ -30,7 +34,7 @@ class File(Calc):
 
     def _calc_readme(self):
         ans = self.prog.pp.get("project", "readme")
-        if type(ans) is str:
+        if type(ans) is str and os.path.exists(ans):
             return ans
         return self._find("README.rst")
 
