@@ -3,17 +3,8 @@ import os
 import string
 import sys
 
-import v440
-
 from petrus._core import utils
 from petrus._core.calcs.Calc import Calc
-from petrus._core.Version import Version
-
-CLASSIFIERS = [
-    "Programming Language :: Python",
-    "Programming Language :: Python :: 3",
-    "Programming Language :: Python :: 3 :: Only",
-]
 
 
 class Project(Calc):
@@ -31,7 +22,7 @@ class Project(Calc):
         for k, v in a.items():
             if v:
                 author[k] = v
-        author = utils.easy_dict(author)
+        author = self.prog.easy_dict(author)
         used = False
         for i in range(len(ans)):
             try:
@@ -41,20 +32,43 @@ class Project(Calc):
             fit = utils.dict_match(ans[i], author)
             if fit and not used:
                 ans[i].update(author)
-            ans[i] = utils.easy_dict(ans[i])
+            ans[i] = self.prog.easy_dict(ans[i])
             used |= fit
         if not used:
             ans.insert(0, author)
         return ans
 
     def _calc_classifiers(self):
-        ans = self.get("classifiers")
-        if ans is not None:
+        preset = self.get("classifiers", default=[])
+        if type(preset) is not list:
+            return preset
+        if utils.isfile(self.prog.file.license):
+            mit = ""
+        else:
+            mit = "License :: OSI Approved :: MIT License"
+        kwarg = self.prog.kwargs["classifiers"]
+        if kwarg == "":
+            preset = utils.easy_list(preset)
+            return preset
+        ans = kwarg
+        preset = ", ".join(preset)
+        ans = ans.format(preset=preset, mit=mit)
+        ans = ans.split(",")
+        ans = self.format_classifiers(ans)
+        if self.prog.development_status == "":
+            ans = self.prog.easy_list(ans)
             return ans
-        ans = CLASSIFIERS
-        if not utils.isfile(self.prog.file.license):
-            ans += ["License :: OSI Approved :: MIT License"]
-        ans = utils.easy_list(ans)
+        prefix = "Development Status :: "
+        cleaned = list()
+        for x in ans:
+            if x.lower().startswith(prefix.lower()):
+                continue
+            cleaned.append(x)
+        ans = cleaned
+        status = prefix + self.prog.development_status
+        ans.append(status)
+        ans = self.format_classifiers(ans)
+        ans = self.prog.easy_list(ans)
         return ans
 
     def _calc_dependencies(self):
@@ -62,7 +76,7 @@ class Project(Calc):
         if type(ans) is not list:
             return ans
         ans = [utils.fix_dependency(x) for x in ans]
-        ans = utils.easy_list(ans)
+        ans = self.prog.easy_list(ans)
         return ans
 
     def _calc_description(self):
@@ -87,17 +101,32 @@ class Project(Calc):
 
     def _calc_name(self):
         basename = os.path.basename(os.getcwd())
-        return self.get("name") or basename
+        raw = self.get("name") or basename
+        raw = str(raw)
+        ans = ""
+        for x in raw:
+            if x in (string.ascii_letters + string.digits):
+                ans += x
+            else:
+                ans += "_"
+        return ans
 
     def _calc_readme(self):
         return self.prog.file.readme
 
     def _calc_requires_python(self):
-        return (
-            self.get("requires-python")
-            or self.prog.kwargs["requires_python"]
-            or ">={0}.{1}.{2}".format(*sys.version_info)
-        )
+        kwarg = self.prog.kwargs["requires_python"]
+        preset = self.get("requires-python", default="")
+        current = ">={0}.{1}.{2}".format(*sys.version_info)
+        if kwarg == "":
+            return preset
+        kwarg = kwarg.format(preset=preset, current=current)
+        kwarg = kwarg.split("\\|")
+        kwarg = [x.strip() for x in kwarg]
+        for x in kwarg:
+            if x:
+                return x
+        return None
 
     def _calc_urls(self):
         ans = self.get("urls")
@@ -107,51 +136,27 @@ class Project(Calc):
             return ans
         if self.prog.github:
             ans.setdefault("Source", self.prog.github)
+        p = f"https://pypi.org/project/{self.name}/"
+        ans.setdefault("Index", p)
         p = f"https://pypi.org/project/{self.name}/#files"
         ans.setdefault("Download", p)
-        ans = utils.easy_dict(ans)
+        ans = self.prog.easy_dict(ans)
         return ans
 
     def _calc_version(self):
-        a = self.prog.kwargs["v"]
-        try:
-            args = self.parse_bump(a)
-        except ValueError as e:
-            print(str(e), repr(e))
-            print("\n" * 10)
-            return a
-        b = self.get("version", default="0.0.0")
-        try:
-            c = v440.Version(b)
-            c.bump(*args)
-        except:
-            return b
-        return str(c)
+        return self.prog.version_formatted
+
+    @classmethod
+    def format_classifiers(cls, ans, /):
+        ans = [x.replace("::", " :: ") for x in ans]
+        ans = [" ".join(x.split()) for x in ans]
+        ans = [x.strip() for x in ans]
+        ans = [x for x in ans if x]
+        return ans
 
     def get(self, *args, default=None):
         return self.prog.pp.get("project", *args, default=default)
 
-    @staticmethod
-    def parse_bump(line):
-        line = line.strip()
-        if not line.startswith("bump"):
-            raise ValueError
-        line = line[4:].lstrip()
-        if not line.startswith("("):
-            raise ValueError
-        line = line[1:].lstrip()
-        if not line.endswith(")"):
-            raise ValueError
-        line = line[:-1].rstrip()
-        if line.endswith(","):
-            line = line[:-1].rstrip()
-        chars = string.digits + string.whitespace + ",-"
-        if line.strip(chars):
-            raise ValueError
-        line = line.split(",")
-        line = [int(x.strip()) for x in line]
-        return line
-
     def todict(self) -> None:
         ans = self.get(default={})
         prefix = "_calc_"
@@ -160,7 +165,9 @@ class Project(Calc):
                 continue
             k = n[len(prefix) :]
             v = getattr(self, k)
+            if v is None:
+                continue
             k = k.replace("_", "-")
             ans[k] = v
-        ans = utils.easy_dict(ans)
+        ans = self.prog.easy_dict(ans)
         return ans
